==> pari-2.3.4.tbz: include/pari/paricfg.h <==
/*  This file was created by Configure. Any change made to it will be lost
 *  next time Configure is run. */
#ifndef __CONFIG_H__
#define __CONFIG_H__
#define UNIX
#define GPHELP ""
#define GPDATADIR "/usr/local/share/pari"
#define SHELL_Q '\''

#define PARIVERSION "GP/PARI CALCULATOR Version 2.3.4 (released)"
#ifdef __cplusplus
# define PARIINFO "C++ amd64 running freebsd (portable C kernel) 64-bit version"
#else
# define PARIINFO "amd64 running freebsd (portable C kernel) 64-bit version"
#endif
#define PARI_VERSION_CODE 131844
#define PARI_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
#define PARI_VERSION_SHIFT 8

#define PARI_DOUBLE_FORMAT -
#define GCC_VERSION "4.2.1 20070719  [FreeBSD]"
#define __HAS_NO_ASM__
#define ASMINLINE

/*  Location of GNU gzip program (enables reading of .Z and .gz files). */
#define GNUZCAT
#define ZCAT "/usr/bin/gzip -dc"

/*  Use GNU readline library
 *  This is incompatible with SUN commandtools (not with shelltools).
 */
#define READLINE "5.2"
#define HAS_COMPLETION_APPEND_CHAR
#define HAS_RL_GENERIC_BIND
#define HAS_RL_SAVE_PROMPT
#define HAS_RL_MESSAGE
#define HAS_RL_COMPLETION_MATCHES
#define HAS_RL_COMPLETION_FUNC_T
#define HAS_HISTORY_H
#define HAS_RL_ATTEMPTED_COMPLETION_OVER
#define HAS_RL_COMPLETION_QUERY_ITEMS
#define HAS_RL_BIND_KEY_IN_MAP
#define HAS_RL_LIBRARY_VERSION

#define LONG_IS_64BIT
#define HAS_EXP2
#define USE_GETRUSAGE 1
#define HAS_SIGACTION
#define HAS_DLOPEN
#define STACK_CHECK
#define HAS_VSNPRINTF
#define HAS_TIOCGWINSZ
#define HAS_STRFTIME
#define HAS_STAT
#endif

==> pari-2.3.4_1.tbz: include/pari/paricfg.h <==
/*  This file was created by Configure. Any change made to it will be lost
 *  next time Configure is run. */
#ifndef __CONFIG_H__
#define __CONFIG_H__
#define UNIX
#define GPHELP ""
#define GPDATADIR "/usr/local/share/pari"
#define SHELL_Q '\''

#define PARIVERSION "GP/PARI CALCULATOR Version 2.3.4 (released)"
#ifdef __cplusplus
# define PARIINFO "C++ i386 running freebsd (ix86/GMP-4.2.4 kernel) 32-bit version"
#else
# define PARIINFO "i386 running freebsd (ix86/GMP-4.2.4 kernel) 32-bit version"
#endif
#define PARI_VERSION_CODE 131844
#define PARI_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
#define PARI_VERSION_SHIFT 8

#define PARI_DOUBLE_FORMAT 1
#define GCC_VERSION "4.2.1 20070719  [FreeBSD]"
#define ASMINLINE

/*  Location of GNU gzip program (enables reading of .Z and .gz files). */
#define GNUZCAT
#define ZCAT "/usr/bin/gzip -dc"

/*  Use GNU readline library
 *  This is incompatible with SUN commandtools (not with shelltools).
 */
#define READLINE "5.2"
#define HAS_COMPLETION_APPEND_CHAR
#define HAS_RL_GENERIC_BIND
#define HAS_RL_SAVE_PROMPT
#define HAS_RL_MESSAGE
#define HAS_RL_COMPLETION_MATCHES
#define HAS_RL_COMPLETION_FUNC_T
#define HAS_HISTORY_H
#define HAS_RL_ATTEMPTED_COMPLETION_OVER
#define HAS_RL_COMPLETION_QUERY_ITEMS
#define HAS_RL_BIND_KEY_IN_MAP
#define HAS_RL_LIBRARY_VERSION

#define HAS_EXP2
#define USE_GETRUSAGE 1
#define HAS_SIGACTION
#define HAS_DLOPEN
#define STACK_CHECK
#define HAS_VSNPRINTF
#define HAS_TIOCGWINSZ
#define HAS_STRFTIME
#define HAS_STAT
#endif
